@@ -3,11 +3,7 @@ from datetime import datetime
 import dateutil.parser
 import pytz
 
-from blockapi.services import (
-    BlockchainAPI,
-    set_default_args_values,
-    AddressNotExist,
-)
+from blockapi.services import AddressNotExist, BlockchainAPI, set_default_args_values
 
 
 class BlockchairAPI(BlockchainAPI):
@@ -34,7 +30,7 @@ class BlockchairAPI(BlockchainAPI):
     supported_requests = {
         # for limit and offset the second parameter 0 is for utxo
         'get_dashboard': '/{name}/dashboards/{address_type}'
-                         '/{address}?limit={limit},0&offset={offset},0',
+        '/{address}?limit={limit},0&offset={offset},0',
         'get_txs': '/{name}/dashboards/transactions/{hash_or_hashes}',
     }
 
@@ -43,8 +39,7 @@ class BlockchairAPI(BlockchainAPI):
         self._set_address_type()
 
     def _set_address_type(self):
-        is_xpub = (any(self.address.startswith(p)
-                       for p in ['xpub', 'ypub', 'zpub']))
+        is_xpub = any(self.address.startswith(p) for p in ['xpub', 'ypub', 'zpub'])
         self.address_type = 'xpub' if is_xpub else 'address'
 
     def get_balance(self):
@@ -72,9 +67,7 @@ class BlockchairAPI(BlockchainAPI):
 
         tx_hashes = dashboard['transactions']
         tx_response = self.request(
-            'get_txs',
-            symbol=self.symbol,
-            hash_or_hashes=','.join(tx_hashes)
+            'get_txs', symbol=self.symbol, hash_or_hashes=','.join(tx_hashes)
         )
         if not tx_response.get('data'):
             return []
@@ -83,24 +76,32 @@ class BlockchairAPI(BlockchainAPI):
         return [self.parse_tx(t) for t in txs]
 
     def parse_tx(self, tx):
-        my_input = next((i for i in tx['inputs']
-                         if self.address == i['recipient']), None)
-        my_output = next((o for o in tx['outputs']
-                          if self.address == o['recipient']), None)
+        my_input = next(
+            (i for i in tx['inputs'] if self.address == i['recipient']), None
+        )
+        my_output = next(
+            (o for o in tx['outputs'] if self.address == o['recipient']), None
+        )
         tx_data = tx['transaction']
 
         if my_input:
             amount = my_input['value'] * self.coef
             direction = 'outgoing'
             from_address = self.address
-            to_address = (tx['outputs'][0]['recipient']
-                          if tx_data['output_count'] == 1 else 'multiple')
+            to_address = (
+                tx['outputs'][0]['recipient']
+                if tx_data['output_count'] == 1
+                else 'multiple'
+            )
         else:
             amount = my_output['value'] * self.coef
             direction = 'incoming'
             to_address = self.address
-            from_address = (tx['inputs'][0]['recipient']
-                            if tx_data['input_count'] == 1 else 'multiple')
+            from_address = (
+                tx['inputs'][0]['recipient']
+                if tx_data['input_count'] == 1
+                else 'multiple'
+            )
 
         return {
             'date': dateutil.parser.parse(tx_data['time']),
@@ -115,7 +116,7 @@ class BlockchairAPI(BlockchainAPI):
             'type': 'normal',
             'kind': 'transaction',
             'direction': direction,
-            'raw': tx
+            'raw': tx,
         }
 
     def _get_dashboard(self, offset=0, limit=0):
@@ -126,7 +127,7 @@ class BlockchairAPI(BlockchainAPI):
             address_type=self.address_type,
             address=self.address,
             offset=offset,
-            limit=limit
+            limit=limit,
         )
 
         data = response.get('data')
