@@ -6,7 +6,7 @@ class ChainSoAPI(BlockchainAPI):
     Multi coins: bitcoin, litecoin, dogecoin, zcash, dash
     Does't support xpub/ypub/zpub :(
     API docs: https://sochain.com/api
-    Explorer: 
+    Explorer:
     """
 
     active = True
@@ -21,7 +21,8 @@ class ChainSoAPI(BlockchainAPI):
 
     supported_requests = {
         'get_balance': '/get_address_balance/{symbol}/{address}',
-        'get_txs': '/address/{symbol}/{address}'
+        'get_txs': '/address/{symbol}/{address}',
+        'get_unspent': '/get_tx_unspent/{symbol}/{address}',
     }
 
     def __init__(self, address, api_key=None):
@@ -49,6 +50,14 @@ class ChainSoAPI(BlockchainAPI):
 
         return [self.parse_tx(t) for t in txs]
 
+    def get_unspent(self):
+        # https://chain.so/api/#get-unspent-tx
+        response = self._request('get_unspent')
+        if not response:
+            return None
+
+        return response
+
     @staticmethod
     def parse_tx(tx):
         return tx
