@@ -6,7 +6,7 @@ class GreymassAPI(BlockchainAPI):
     coins: eos
     API docs: https://github.com/greymass/eosio-api-ext/wiki
     /API-Request-Response-Examples
-    Explorer: 
+    Explorer:
     """
 
     active = True
@@ -25,17 +25,21 @@ class GreymassAPI(BlockchainAPI):
 
     def get_balance(self):
         body = '{"account": "' + self.address + '"}'
-        response = self.request('get_balance',
-                                body=body)
+        response = self.request('get_balance', body=body)
         if not response:
             return None
 
         # {‘symbol’: _, ‘address’: _, ‘price’: _, ‘name’: ?} ]
 
         try:
-            return [{"symbol": item["symbol"],
-                     "address": item["code"], 
-                     "amount": float(item["amount"]),
-                     "name": None} for item in response]
+            return [
+                {
+                    "symbol": item["symbol"],
+                    "address": item["code"],
+                    "amount": float(item["amount"]),
+                    "name": None,
+                }
+                for item in response
+            ]
         except KeyError:
             return None
